/**
 * The type of scalar values supported by SqliteStore.
 *
 * This is a subset of all types supported by Sqlite itself, but
 * may expand in the future if more types need to be used in LDS.
 */
export type SqliteType = string | number | null;
/**
 * A result from executing a query against a SqliteStore.
 *
 * This type is a compromise between efficiency and ergonomics
 * that hopefully strikes a good balance. It includes the column
 * names in the result but avoids duplicating them for every row
 * in the result set. Rows are packed as an array of arrays of
 * values.
 *
 * Each row array is expected to contain the same number of values
 * as the columns array, and the order of items in a row corresponds
 * to the order in the columns array.
 */
export interface SqliteResult {
    columns: string[];
    rows: SqliteType[][];
}
/**
 * A `SqliteStore` is a durable store type that is backed by a
 * Sqlite database with a well-known schema.
 *
 * Example implementations of this interface might be a native
 * implementation using SQLCipher, or a browser implementation
 * that uses sqlite.js.
 *
 * Because all implementations of this interface are known to be
 * powered by Sqlite, the store can safely make use of
 * features such as views, partial indexes, virtual columns, and
 * extensions that are part of Sqlite.
 */
export interface SqliteStore {
    /**
     * Generally, all SqliteStore implementations should support raw SQL queries.
     * However, an implementation may choose to return `false` in some cases, e.g.
     * if the schema version at runtime does not match any currently supported or
     * well-known schema revisions.
     *
     * @returns true if the implementation supports SQL evaluation.
     */
    isEvalSupported(): boolean;
    /**
     * Checks to see if the plugin supports batch updates
     */
    isBatchUpdateSupported(): boolean;
    /**
     * Executes the specified query and returns the result.
     *
     * This method will eagerly retrieve all rows of the result set and
     * include them in the returned result object.
     *
     * NOTE: positional parameters are bound first, followed by named parameters.
     *
     * @param sql the sql query to execute
     * @param params an array of positional parameters used in the `sql` query
     * @see sqlite3_exec
     */
    query(sql: string, params: SqliteType[]): Promise<SqliteResult>;
}
